hstrat.hstrat.stratum\_retention\_condemners.StratumRetentionCondemnerFromPredicate
===================================================================================

.. currentmodule:: hstrat.hstrat.stratum_retention_condemners

.. autofunction:: StratumRetentionCondemnerFromPredicate